Adding new text files to a project
Date: 06 22, 2001 3:11:48 PM

# Adding New Text Tiles to a Project

There are several ways to add new text files to an analyzer project.

To add a text file using the Text Tab:

1. In your analyzer project, click on the Text Tab.

2. With the mouse in the Text Tab, right-click and select Add > New Text File.

3. In the dialog box, give the text file a name. You do not need to add the .txt extension to the file.

4. Click OK to finish creating the text file. The newly created text file opens up in the Workspace. (The text file is stored in the input folder of the analyzer project.)

To add a text file using File > New:

1. From the File menu, select New. A blank text file with a default VisualText title opens up in the Workspace. (You don't have to be in the Text Tab.)

2. To save the text file in your analyzer project, right-click on the text file and select Save As. Navigate to the location in the input directory for the current analyzer project where you would like to save the text file.

3. In the Save As dialog, give the text file a name.

4. Click Save to finish creating the text file.

5. To see the file in the Text Tab, right-click in the Text Tab and select, Refresh.

6. You will be prompted with a warning saying that refreshing the Text Tab will cause all knowledge associated with the text files in the Text Tab to be lost. Answer Yes if you are not concerned with losing any information.